store

package
v0.0.0-...-7e7fb06 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 21, 2017 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Backend

type Backend interface {
	CmdBackend
	TokenBackend
}

func Selected

func Selected() Backend

type CmdBackend

type CmdBackend interface {
	List(user string) []*core.Command
	Get(user, name string) *core.Command
	Put(user, name string, cmd *core.Command) error
	Delete(user, name string) error
	GrantAccess(owner, name string, subject ...string) error
	RevokeAccess(owner, name string, subject ...string) error
	GrantAdmin(owner, name string, subject ...string) error
	RevokeAdmin(owner, name string, subject ...string) error
}

type TokenBackend

type TokenBackend interface {
	ListTokens(user string) ([]*core.Token, error)
	GetToken(key string) (*core.Token, error)
	PutToken(token *core.Token) error
	DeleteToken(key string) error
}

Directories

Path Synopsis
Package dynamodb implements a dynamodb store backend with migration support.
Package dynamodb implements a dynamodb store backend with migration support.

Jump to