maint

package
v0.0.0-...-7e7fb06 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 21, 2017 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Active

func Active() bool

Active returns current maintenance state

func Allowed

func Allowed() []string

Allowed returns a slice of users which are allowed access during maintenance

func IsAllowed

func IsAllowed(name string) bool

IsAllowed returns true if name is allowed access during maintenance

func Notice

func Notice() string

Notice printed during maintenance

Types

type Component

type Component struct {
}

Component ...

func (*Component) AppPreStart

func (c *Component) AppPreStart() error

func (*Component) PreprocessOrder

func (c *Component) PreprocessOrder() uint

func (*Component) PreprocessSession

func (c *Component) PreprocessSession(sess ssh.Session) (cont bool, msg string)

Jump to